Description: Shrink (tls-)basic-realistic tests
 Reduce the message count so they reliably succeed on slow platforms like
 riscv64. Fast platforms work too.
Author: Matthew Ruffell <matthew.ruffell@canonical.com>

Index: librelp-1.9.0/tests/basic-realistic.sh
===================================================================
--- librelp-1.9.0.orig/tests/basic-realistic.sh	2021-01-26 09:19:29.368570620 +1300
+++ librelp-1.9.0/tests/basic-realistic.sh	2021-01-26 09:19:29.312572186 +1300
@@ -3,7 +3,7 @@
 # a more relastic test which actually sends a bit larger number
 # of messages
 . ${srcdir:=$(pwd)}/test-framework.sh
-NUMMESSAGES=50000
+NUMMESSAGES=10000
 startup_receiver
 ./send -t 127.0.0.1 -p $TESTPORT -n$NUMMESSAGES $OPT_VERBOSE
 stop_receiver
Index: librelp-1.9.0/tests/tls-basic-realistic.sh
===================================================================
--- librelp-1.9.0.orig/tests/tls-basic-realistic.sh	2021-01-26 09:19:29.368570620 +1300
+++ librelp-1.9.0/tests/tls-basic-realistic.sh	2021-01-26 09:19:29.364570732 +1300
@@ -3,7 +3,7 @@
 # a more relastic test which actually sends a bit larger number
 # of messages
 . ${srcdir:=$(pwd)}/test-framework.sh
-NUMMESSAGES=50000
+NUMMESSAGES=10000
 
 function actual_test() {
 	startup_receiver --tls-lib $TEST_TLS_LIB -T -a "name" -x ${srcdir}/tls-certs/ca.pem \
