Description: Shrink (tls-)receiver-abort tests
 Reduce the message count so they reliably succeed on slow platforms like
 riscv64. Fast platforms work too.
Author: William Grant <wgrant@ubuntu.com>

Index: librelp-1.9.0-1ubuntu1/tests/receiver-abort.sh
===================================================================
--- librelp-1.9.0-1ubuntu1.orig/tests/receiver-abort.sh	2021-01-06 17:15:14.209477534 +1300
+++ librelp-1.9.0-1ubuntu1/tests/receiver-abort.sh	2021-01-06 17:15:14.205477483 +1300
@@ -5,11 +5,11 @@
 . ${srcdir:=$(pwd)}/test-framework.sh
 # export OPT_VERBOSE=-v # uncomment for debugging 
 export errorlog="error.$LIBRELP_DYN.log"
-export NUMMESSAGES=100000
+export NUMMESSAGES=10000
 check_command_available timeout
 
 startup_receiver -e ${TESTDIR}/${errorlog}
-./send -t 127.0.0.1 -p $TESTPORT -n$NUMMESSAGES --no-exit-on-error --kill-on-msg 20000 --kill-pid $RECEIVE_PID $OPT_VERBOSE &
+./send -t 127.0.0.1 -p $TESTPORT -n$NUMMESSAGES --no-exit-on-error --kill-on-msg 2000 --kill-pid $RECEIVE_PID $OPT_VERBOSE &
 SENDER_PID=$!
 
 for i in {1..3};  do
Index: librelp-1.9.0-1ubuntu1/tests/tls-receiver-abort.sh
===================================================================
--- librelp-1.9.0-1ubuntu1.orig/tests/tls-receiver-abort.sh	2021-01-06 17:15:14.209477534 +1300
+++ librelp-1.9.0-1ubuntu1/tests/tls-receiver-abort.sh	2021-01-06 17:15:14.205477483 +1300
@@ -4,12 +4,12 @@
 # of messages
 . ${srcdir:=$(pwd)}/test-framework.sh
 check_command_available timeout
-export NUMMESSAGES=100000
+export NUMMESSAGES=10000
 
 actual_test() {
 	startup_receiver
 	./send -t 127.0.0.1 -p $TESTPORT -n$NUMMESSAGES --no-exit-on-error \
-		--kill-on-msg 20000 --kill-pid $RECEIVE_PID $OPT_VERBOSE &
+		--kill-on-msg 2000 --kill-pid $RECEIVE_PID $OPT_VERBOSE &
 	SENDER_PID=$!
 
 	for i in {1..3};  do
